@@ -106,7 +106,7 @@ class Broadcast:
             for task in done_tasks:
                 if task.exception().__class__ is PropagationCancelled:
                     break
-            
+
     async def Executor(
         self,
         target: Union[Callable, ExecTarget],
@@ -169,7 +169,10 @@ class Broadcast:
                         for name, annotation, default in argument_signature(
                             target_callable
                         ):
-                            if target.param_paths.setdefault(name, initial_path) is initial_path:
+                            if (
+                                target.param_paths.setdefault(name, initial_path)
+                                is initial_path
+                            ):
                                 target.param_paths[name + "$set"] = set()
                             parameter_compile_result[name] = await dii.lookup_param(
                                 name, annotation, default, target.param_paths[name]
@@ -213,6 +216,14 @@ class Broadcast:
                     self.postEvent(ExceptionThrowed(exception=e, event=event))
                 raise
             finally:
+                if not complete_finished:
+                    _, exception, tb = sys.exc_info()
+                    await dii.exec_lifecycle("afterDispatch", exception, tb)
+                    await dii.exec_lifecycle("afterTargetExec", exception, tb)
+                    await dii.exec_lifecycle("afterExecution", exception, tb)
+                else:
+                    await dii.exec_lifecycle("afterDispatch")
+
                 if is_exectarget and not track_logs.fluent_success:
                     current_paths = target.param_paths
                     current_path: List[List["T_Dispatcher"]] = None
@@ -225,19 +236,18 @@ class Broadcast:
                             current_path_set = current_paths[log[1] + "$set"]
                         elif log[0] is TrackLogType.LookupEnd:
                             current_path = None
-                        elif log[0] is TrackLogType.Result and log[2] not in current_path_set:
+                        elif (
+                            log[0] is TrackLogType.Result
+                            and log[2] not in current_path_set
+                        ):
                             current_path[0].append(log[2])
                             current_path_set.add(log[2])
                         elif log[0] is TrackLogType.Continue:
                             has_failures.add(log[1])
 
                     target.maybe_failure.symmetric_difference_update(has_failures)
-                if complete_finished:
-                    _, exception, tb = sys.exc_info()
-                    await dii.exec_lifecycle("afterTargetExec", exception, tb)
-                    await dii.exec_lifecycle("afterExecution", exception, tb)
-                else:
-                    await dii.exec_lifecycle("afterDispatch")
+
+                
 
             if result.__class__ is Force:
                 return result.content
