@@ -1,6 +1,7 @@
 from enum import IntEnum, auto
 from typing import Any, List, Tuple, NamedTuple
 
+
 class TrackLogType(IntEnum):
     LookupStart = auto()
     LookupEnd = auto()
@@ -10,14 +11,16 @@ class TrackLogType(IntEnum):
 
     RequirementCrashed = auto()
 
+
 T_TrackLogItem = Tuple[TrackLogType, Any]
 
+
 class TrackLog:
-    __slots__ = ('log', 'fluent_success')
+    __slots__ = ("log", "fluent_success")
 
     def __init__(self) -> None:
         self.log = []
         self.fluent_success = True
 
     log: List[T_TrackLogItem]
-    fluent_success: bool
\ No newline at end of file
+    fluent_success: bool
